/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.its.trac;

// Bridge API from com.rempl.readers.its:bridge-its-api
import com.rempl.readers.its.bridge.Change;

// REMPL API from com.rempl:rempl-api
import com.ymock.util.Logger;

// array manipulations
import org.apache.commons.lang.ArrayUtils;

/**
 * Legally ignores the tuple, without any debug message. Otherwise,
 * if the tuple is not possible to be ignored it passes certain
 * log message to the logger. This class is
 * part of Chain of Responsibility managed by {@link AbstractChangeBuilder}.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: CbLegallyIgnore.java 1734 2011-08-03 05:25:29Z yegor256@yahoo.com $
 */
final class CbLegallyIgnore extends AbstractChangeBuilder {

    /**
     * {@inheritDoc}
     */
    @Override
    protected Change buildIt(final TracTuple tuple) {
        if (this.isIgnored(tuple.field())) {
            Logger.debug(
                this,
                "#build(%s): legally ignored",
                tuple
            );
        } else {
            Logger.warn(
                this,
                "#make(%s): unrecognized change, ignored",
                tuple
            );
        }
        return null;
    }

    /**
     * Make change object from the data elements provided.
     * @param field Name of Trac field
     * @return Shall we ignore?
     * @see #make(Date, Person, String, Object)
     */
    private boolean isIgnored(final String field) {
        final String[] fields = new String[] {
            "attachment",
            "_comment0",
            "_comment1",
            "_ts",
            "cc",
            "changetime",
            "component",
            "keywords",
            "milestone",
            "priority",
            // @checkstyle MultipleStringLiterals (1 line)
            "reporter",
            "time",
            "type",
            "version",
        };
        return ArrayUtils.contains(fields, field);
    }

}
