/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.its.trac;

// Bridge API from com.rempl.readers.its:bridge-its-api
import com.rempl.readers.its.bridge.Change;
import com.rempl.readers.its.bridge.ChangeStatus;

/**
 * Builder of {@link Change} from {@link TracTuple}, if this
 * tuple is about <tt>STATUS</tt> field in Trac. This class is
 * part of Chain of Responsibility managed by {@link AbstractChangeBuilder}.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: CbStatus.java 1389 2011-05-23 23:07:59Z guard $
 */
final class CbStatus extends AbstractChangeBuilder {

    /**
     * {@inheritDoc}
     */
    @Override
    protected Change buildIt(final TracTuple tuple) {
        if (!"resolution".equals(tuple.field())
            && !"status".equals(tuple.field())) {
            return null;
        }
        ChangeStatus.Status status;
        if ("".equals((String) tuple.value())) {
            status = ChangeStatus.Status.OPEN;
        } else if ("closed".equals((String) tuple.value())) {
            status = ChangeStatus.Status.FIXED;
        } else {
            status = ChangeStatus.Status.INVALID;
        }
        return new ChangeStatus(
            tuple.author(),
            tuple.time(),
            status
        );
    }

}
