/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.its.trac;

// Bridge API from com.rempl.readers.its:bridge-its-api
import com.rempl.readers.its.bridge.BridgeException;
import com.rempl.readers.its.bridge.IssueUrlBuilder;

// bridge utils from com.rempl.readers:readers-bridge-utils
import com.rempl.readers.utils.URLBuilder;

// for manipulation of URLs
import java.net.URL;

// for manipulation of params
import java.util.Map;

/**
 * One issue in Trac, builder of its URL.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: TracIssueUrlBuilder.java 1389 2011-05-23 23:07:59Z guard $
 */
public final class TracIssueUrlBuilder implements IssueUrlBuilder {

    /**
     * URL of Trac.
     */
    private String url;

    /**
     * {@inheritDoc}
     */
    @Override
    public void configure(final Map<String, String> params)
        throws BridgeException {
        if (!params.containsKey(XmlRpcBridge.KEY_URL)) {
            throw new BridgeException(
                "Configuration parameter \""
                + XmlRpcBridge.KEY_URL
                + "\" is mandatory"
            );
        }
        this.url = new URLBuilder(params.get(XmlRpcBridge.KEY_URL))
            .build()
            .toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public URL build(final String name) {
        return new URLBuilder(this.url)
            .append("ticket")
            .append(Integer.valueOf(name).toString())
            .build();
    }

}
