/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.its.trac;

// Bridge API from com.rempl.readers.its:bridge-its-api
import com.rempl.readers.its.bridge.Person;

// for manipulation with dates
import java.util.Date;

/**
 * One tuple from Trac.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: TracTuple.java 1389 2011-05-23 23:07:59Z guard $
 * @see <a href="http://trac-hacks.org/wiki/XmlRpcPlugin">XmlRpcPlugin</a>
 */
final class TracTuple {

    /**
     * Time of the tuple creation.
     */
    private final Date time;

    /**
     * Author of the tuple.
     */
    private final Person author;

    /**
     * Field name being changed.
     */
    private final String field;

    /**
     * New value of the field.
     */
    private final Object value;

    /**
     * Public ctor.
     * @param ptime Time/date of changes made
     * @param pauthor Author of the change
     * @param pfield Name of field changing
     * @param pvalue The value of it
     * @checkstyle ParameterNumber (2 lines)
     */
    public TracTuple(final Date ptime, final Person pauthor,
        final String pfield, final Object pvalue) {
        this.time = ptime;
        this.author = pauthor;
        this.field = pfield;
        this.value = pvalue;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return String.format(
            "%s;%s;%s;%s",
            this.time,
            this.author,
            this.field,
            this.value
        );
    }

    /**
     * Getter of internal field.
     * @return The value of the field
     */
    public Date time() {
        return this.time;
    }

    /**
     * Getter of internal field.
     * @return The value of the field
     */
    public Person author() {
        return this.author;
    }

    /**
     * Getter of internal field.
     * @return The value of the field
     */
    public String field() {
        return this.field;
    }

    /**
     * Getter of internal field.
     * @return The value of the field
     */
    public Object value() {
        return this.value;
    }

}
